diff --git a/ChangeLog b/ChangeLog
index 3caf8687995744d67d3699476372bd6d7ed3cb1f_Q2hhbmdlTG9n..5203b1f65690390cf865fa20127add6942aca096_Q2hhbmdlTG9n 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,7 @@
+2000-10-05  Martin Buchholz  <martin@xemacs.org>
+
+	* *: Mega typo fix.
+
 2000-09-15  Adrian Aichner  <aichner@ecf.teradyne.com>
 
 	* crypt.el (crypt-find-file-hook): Fix (null-buffer-file-name)
diff --git a/terminal.el b/terminal.el
index 3caf8687995744d67d3699476372bd6d7ed3cb1f_dGVybWluYWwuZWw=..5203b1f65690390cf865fa20127add6942aca096_dGVybWluYWwuZWw= 100644
--- a/terminal.el
+++ b/terminal.el
@@ -1198,7 +1198,7 @@
 ;; This is only separated out from function terminal-emulator
 ;; to keep the latter a little more managable.
 (defun terminal-mode ()
-  "Set up variables for use f the terminal-emualtor.
+  "Set up variables for use of the terminal-emulator.
 One should not call this -- it is an internal function
 of the terminal-emulator"
   (kill-all-local-variables)
diff --git a/mchat.el b/mchat.el
index 3caf8687995744d67d3699476372bd6d7ed3cb1f_bWNoYXQuZWw=..5203b1f65690390cf865fa20127add6942aca096_bWNoYXQuZWw= 100644
--- a/mchat.el
+++ b/mchat.el
@@ -38,7 +38,7 @@
 
 ;; #### NOTE: before using this package, you most likely have to customize the
 ;; `mchat-nsl-method' first. It specifies a program like nsl or nslookup in
 ;; order to retreive the IP number of your machine.
 
 ;; The main entry point to the package is the `mchat' function which allows
 ;; you to open a multicast group based on the MChat protocol. There are a
@@ -97,7 +97,7 @@
 		        (string :tag "Address"))))
 
 (defcustom mchat-message-cache-size 32
-  "*Number of sent messages to remeber for each MChat group."
+  "*Number of sent messages to remember for each MChat group."
   :group 'mchat
   :type 'integer)
 
@@ -184,7 +184,7 @@
     (system-name)
     "\\([0-9]+\\)\\.\\([0-9]+\\)\\.\\([0-9]+\\)\\.\\([0-9]+\\)"
     1)
-  "*Method to use in order to retreive one IP address from your machine. It
+  "*Method to use in order to retrieve one IP address from your machine. It
 looks like (PROGRAM ARGS REGEXP START) where:
 - PROGRAM is the program to be called (a string)
 - ARGS is a lisp expression returning a string of arguments you might want to
@@ -905,7 +905,7 @@
 ;; #### NOTE: for the moment, all of the following functions are supposed to
 ;; be run only from an MChat buffer. Maybe we could make some of them query
 ;; the group otherwise, but there again, I don't find this particularly
-;; usefull.
+;; useful.
 
 (defsubst mchat-interactive ()
   (let* ((grp (assoc mchat-group-name mchat-groups)))
@@ -1329,7 +1329,7 @@
 
 ;;;###autoload
 (defun mchat (name &optional address)
-  "Join MChat multicast group NAME at adress ADDRESS. When called
+  "Join MChat multicast group NAME at address ADDRESS. When called
 interactively, you will be prompted for the group name, and if the group is
 not registered, for the corresponding multicast address. Please refer to
 `mchat-predefined-groups' for a list of known groups, and
@@ -38,7 +38,7 @@
 ;; #### NOTE: before using this package, you most likely have to customize the
 ;; `mchat-nsl-method' first. It specifies a program like nsl or nslookup in
-;; order to retreive the IP number of your machine.
+;; order to retrieve the IP number of your machine.
 
 ;; The main entry point to the package is the `mchat' function which allows